Managers
--------

.. autoclass:: socketio.Manager
   :members:
   :inherited-members:

.. autoclass:: socketio.PubSubManager
   :members:
   :inherited-members:

.. autoclass:: socketio.KombuManager
   :members:
   :inherited-members:

.. autoclass:: socketio.RedisManager
   :members:
   :inherited-members:

.. autoclass:: socketio.KafkaManager
   :members:
   :inherited-members:

.. autoclass:: socketio.ZmqManager
   :members:
   :inherited-members:

.. autoclass:: socketio.AsyncManager
   :members:
   :inherited-members:

.. autoclass:: socketio.AsyncRedisManager
   :members:
   :inherited-members:

.. autoclass:: socketio.AsyncAioPikaManager
   :members:
   :inherited-members:

